@@ -1,4 +1,4 @@
-# $Id: Perl.pm,v 1.120 2008/09/25 22:43:57 turnstep Exp $
+# $Id: Perl.pm,v 1.125 2009/01/26 01:00:25 turnstep Exp $
 
 package Net::SSH::Perl;
 use strict;
@@ -14,6 +14,7 @@ use vars qw( $VERSION $CONFIG $HOSTNAME );
 $CONFIG = {};
 
 use Socket;
+use IO::Socket;
 use Fcntl;
 use Symbol;
 use Carp qw( croak );
@@ -22,7 +23,7 @@ eval {
     $HOSTNAME = hostname();
 };
 
-$VERSION = '1.30_1';
+$VERSION = '1.33_1';
 
 sub VERSION { $VERSION }
 
@@ -219,7 +220,7 @@ sub _create_socket {
     my $ssh = shift;
     my $sock = gensym;
 
-	my ($p,$end,$delta) = (0,1,1);	# normally we use whatever port we can get
+	my ($p,$end,$delta) = (0,1,1); # normally we use whatever port we can get
    	   ($p,$end,$delta) = (1023,512,-1) if $ssh->{config}->get('privileged');
 
 	# allow an explicit bind address
@@ -233,7 +234,7 @@ sub _create_socket {
             croak "Net::SSH: Can't create socket: $!";
         last if not $p or bind($sock, sockaddr_in($p,$addr));
         if ($! =~ /Address already in use/i) {
-            close($sock);
+            close($sock) or warn qq{Could not close socket: $!\n};
             next;
         }
         croak "Net::SSH: Can't bind socket to port $p: $!";
@@ -336,7 +337,7 @@ sub incoming_data {
 
 sub session_id {
     my $ssh = shift;
-    $ssh->{session}{id} = shift if @_;
+    $ssh->{session}{id} = shift if @_ and not defined $ssh->{session}{id};
     $ssh->{session}{id};
 }
 
